diff --git a/sql-words.cabal b/sql-words.cabal
--- a/sql-words.cabal
+++ b/sql-words.cabal
@@ -1,18 +1,23 @@
 name:                sql-words
-version:             0.1.6.4
+version:             0.1.6.5
 synopsis:            SQL keywords data constructors into OverloadedString
-description:         This package contiains SQL keywords constructors defined as
+description:         This package contains SQL keywords constructors defined as
                      OverloadedString literals and helper functions to concate these.
 homepage:            http://khibino.github.io/haskell-relational-record/
 license:             BSD3
 license-file:        LICENSE
 author:              Kei Hibino
 maintainer:          ex8k.hibino@gmail.com
-copyright:           Copyright (c) 2013-2020 Kei Hibino
+copyright:           Copyright (c) 2013-2023 Kei Hibino
 category:            Database
 build-type:          Simple
 cabal-version:       >=1.10
-tested-with:           GHC == 8.8.1, GHC == 8.8.2
+tested-with:           GHC == 9.6.2
+                     , GHC == 9.4.6
+                     , GHC == 9.2.8
+                     , GHC == 9.0.2
+                     , GHC == 8.10.7
+                     , GHC == 8.8.1, GHC == 8.8.2
                      , GHC == 8.6.1, GHC == 8.6.2, GHC == 8.6.3, GHC == 8.6.4, GHC == 8.6.5
                      , GHC == 8.4.1, GHC == 8.4.2, GHC == 8.4.3, GHC == 8.4.4
                      , GHC == 8.2.1, GHC == 8.2.2
diff --git a/src/Language/SQL/Keyword.hs b/src/Language/SQL/Keyword.hs
--- a/src/Language/SQL/Keyword.hs
+++ b/src/Language/SQL/Keyword.hs
@@ -12,7 +12,7 @@
 module Language.SQL.Keyword (
   -- * Module which includes keyword type definition
   module Language.SQL.Keyword.Type,
-  -- * Module which includes functions to concatinate keywords
+  -- * Module which includes functions to concatenate keywords
   module Language.SQL.Keyword.Concat
   ) where
 
diff --git a/src/Language/SQL/Keyword/Internal/Type.hs b/src/Language/SQL/Keyword/Internal/Type.hs
--- a/src/Language/SQL/Keyword/Internal/Type.hs
+++ b/src/Language/SQL/Keyword/Internal/Type.hs
@@ -23,7 +23,7 @@
 import Data.Monoid (Monoid (..))
 
 
--- | Diff String type for low-cost concatination.
+-- | Diff String type for low-cost concatenation.
 newtype DString = DString (String -> String)
 
 -- | Make 'DString' from 'String'
@@ -147,7 +147,7 @@
 instance Semigroup Keyword where
   (<>) = kappend
 
--- | 'Keyword' default concatination separate by space.
+-- | 'Keyword' default concatenation separate by space.
 instance Monoid Keyword where
   mempty  = fromDString mempty
   mappend = (<>)
diff --git a/src/Language/SQL/Keyword/Type.hs b/src/Language/SQL/Keyword/Type.hs
--- a/src/Language/SQL/Keyword/Type.hs
+++ b/src/Language/SQL/Keyword/Type.hs
@@ -19,6 +19,6 @@
 import Language.SQL.Keyword.Internal.Type (Keyword (..), word, wordShow, DString)
 
 
--- | Concatinate keywords into 'String' like unwords
+-- | Concatenate keywords into 'String' like unwords
 unwordsSQL :: [Keyword] -> String
 unwordsSQL =  wordShow . mconcat

diff --git a/src/Language/SQL/Keyword/Concat.hs b/src/Language/SQL/Keyword/Concat.hs
--- a/src/Language/SQL/Keyword/Concat.hs
+++ b/src/Language/SQL/Keyword/Concat.hs
@@ -9,10 +9,10 @@
 -- Stability   : experimental
 -- Portability : unknown
 --
--- Concatinations on 'Keyword' types
+-- Concatenations on 'Keyword' types
 module Language.SQL.Keyword.Concat (
   -- * List concatination functions
   -- $listConcatination
   unwords',
 
   sepBy, parenSepBy,
@@ -44,23 +44,23 @@
 import Language.SQL.Keyword.Internal.Type (Keyword (..), word, wordShow, toDString, fromDString)
 
 
-{- $listConcatination
-Functions to concatinate 'Keyword' list.
+{- $listConcatenation
+Functions to concatenate 'Keyword' list.
 -}
 
 -- | Separate 'Keyword' list with delimiter 'Keyword' and map to 'String' list.
 sepBy' :: [Keyword] -> Keyword -> [String]
 ws `sepBy'` d =  map wordShow . intersperse d $ ws
 
--- | Concatinate 'Keyword' list like unwords on 'String' list.
+-- | Concatenate 'Keyword' list like unwords on 'String' list.
 unwords' :: [Keyword] -> Keyword
 unwords' =  mconcat
 
--- | Concatinate 'String' list into one 'Keyword'.
+-- | Concatenate 'String' list into one 'Keyword'.
 concatStr :: [String] -> Keyword
 concatStr =  word . concat
 
--- | Separate 'Keyword' list with delimiter 'Keyword' and concatinate into one 'Keyword'.
+-- | Separate 'Keyword' list with delimiter 'Keyword' and concatenate into one 'Keyword'.
 sepBy :: [Keyword] -> Keyword -> Keyword
 ws `sepBy` d = concatStr $ ws `sepBy'` d
 
@@ -69,10 +69,10 @@
 ws `parenSepBy` d = concatStr $ "(" : (ws `sepBy'` d) ++ [")"]
 
 {- $binaryOperators
-Binary operators on SQL. Result is concatinated into one 'Keyword'.
+Binary operators on SQL. Result is concatenated into one 'Keyword'.
 -}
 
--- | Directly concatinate SQL string without whitespaces.
+-- | Directly concatenate SQL string without whitespaces.
 (<++>) :: Keyword -> Keyword -> Keyword
 x <++> y = fromDString $ toDString x <> toDString y
 
@@ -97,7 +97,7 @@
 (|*|) :: Keyword -> Keyword -> Keyword
 (|*|)  =  defineBinOp' ", "
 
--- | Binary operator for SQL string expression concatination.
+-- | Binary operator for SQL string expression concatenation.
 (.||.) :: Keyword -> Keyword -> Keyword
 (.||.) =  defineBinOp "||"
 
@@ -145,7 +145,7 @@
   d []       = mempty
   d xs@(_:_) = foldr1 op xs
 
--- | Define unary operator on 'Keyword' type represeted by specified 'Keyword'.
+-- | Define unary operator on 'Keyword' type represented by specified 'Keyword'.
 --   Result is delimited by whitespace like unwords on 'String' list.
 defineUniOp :: Keyword -> Keyword -> Keyword
 defineUniOp op e = mconcat [op, e]
@@ -9,10 +9,10 @@
 module Language.SQL.Keyword.Concat (
-  -- * List concatination functions
-  -- $listConcatination
+  -- * List concatenation functions
+  -- $listConcatenation
   unwords',
 